<?php

if (!class_exists('WP_List_Table')) {
	require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}

class WCOA_Attachment_Table extends WP_List_Table
{
	public function get_columns(): array
	{
		return array(
			'cb'            => '<input type="checkbox" />',
			'post_date'          => __('Date'),
			'post_title'         => __('Name'),
			'order_id'         => __('Order', 'woocommerce'),
			'post_author'          => __('Author'),
			'Actions'   => __('Actions')
		);
	}

	private function get_table_data()
	{
		return WCOA_Attachment::get_list();
	}

	function prepare_items()
	{

		$table_data   = $this->get_table_data();

		$columns = $this->get_columns();
		$hidden = [];
		$sortable = $this->get_sortable_columns();
		$primary  = 'name';
		$this->_column_headers = array($columns, $hidden, $sortable, $primary);

		usort( $table_data, array(&$this, 'usort_reorder'));

		/* pagination */
		$per_page = 15;
		$current_page = $this->get_pagenum();
		$total_items  = count( $table_data );

		$table_data = array_slice( $table_data, ( ( $current_page - 1) * $per_page), $per_page);

		$this->set_pagination_args(array(
			'total_items' => $total_items, // total number of items
			'per_page'    => $per_page, // items to show on a page
			'total_pages' => ceil( $total_items / $per_page ) // use ceil to round up
		));

		$this->items = $table_data;
	}

	public function column_default($item, $column_name)
	{
		$item['Actions'] = self::actions($item['post_id'], $item['order_id']);

		$item['post_author'] = get_userdata( $item['post_author'] )->display_name;

		$item['post_title'] = '<a class="wcoa_nowrap" target="_blank" href="' . $item['guid'] . '">' . $item['post_title'] . '</a>';

		$item['order_id'] = '<a href="' . get_edit_post_link($item['order_id']) . '">#' . $item['order_id'] .'</a>';

		switch ($column_name) {
			case 'post_date':
			case 'post_title':
			case 'order_id':
			case 'post_author':
			default:
				return $item[$column_name];
		}
	}

	public function column_cb($item)
	{
		return sprintf('<input type="checkbox" name="element[]" value="%s" />', $item['post_id'] );
	}

	protected function get_sortable_columns(): array
	{
		return array(
			'post_date'  => array('post_date', false),
			'post_title' => array('post_title', false),
			'order_id' => array('order_id', false),
			'post_author'  => array('post_date', false)
		);
	}

	public function usort_reorder($a, $b): int
	{
		// If no sort, default to user_login
		$order_by = (!empty($_GET['orderby'])) ? $_GET['orderby'] : 'post_date';

		// If no order, default to asc
		$order = (!empty($_GET['order'])) ? $_GET['order'] : 'desc';

		// Determine sort order
		$result = strcmp($a[$order_by], $b[$order_by]);

		// Send final sort direction to usort
		return ($order === 'asc') ? $result : -$result;
	}

	public static function actions(int $attachment_id, int $order_id): string
	{
		$nonce_url = wp_nonce_url("admin-post.php?action=wcoa_delete&attachment_id=$attachment_id", 'wcoa_delete_' . $attachment_id);

		$content = '<div>';
		$content .= '<button id="wcoa-send-email-to-customer" wcoa-order-id="' . $order_id . '" wcoa-attachment-id="' . $attachment_id . '" type="button" class="button wcoa-btn wcoa-att-email"></button>';
		$content .= ' ';
		$content .= '<a href="' . $nonce_url . '" title="' . __('Remove') . '" id="wcoa-delete-attachment" wcoa-order-id="' . $order_id . '" wcoa-attachment-id="' . $attachment_id . '" role="button" class="button wcoa-btn wcoa-att-trash"></a>';
		$content .= '</div>';
		return $content;
	}

}