<?php

class WCOA_Attachment
{
	private $file;

	private $order_id;

	public function __construct(array $file, int $order_id)
	{
		$this->file = $file;

		$this->order_id = $order_id;
	}

	public function save()
	{
		$attachment = self::upload();

		if ($attachment !== false)
		{
			$notification = new WCOA_Notification($this->order_id, $attachment['id']);
			$notification->create_note();

			if ( WCOA_Options::get('email_enabled') === true )
				$notification->send_email();

			return $attachment;
		}

		return false;
	}

	private function upload()
	{
		require_once(ABSPATH . 'wp-admin/includes/image.php');
		require_once(ABSPATH . 'wp-admin/includes/file.php');
		require_once(ABSPATH . 'wp-admin/includes/media.php');

		// check if the file exists
		if (!isset($this->file['name']))
		{
			return false;
		}

		// get the file type from the file name
		$file_type = wp_check_filetype(basename( $this->file['name']));

		// create file in the upload folder
		$attachment = wp_upload_bits($this->file['name'], null, file_get_contents($this->file['tmp_name']));

		$filename = $attachment['file'];

		$title = preg_replace('/\.[^.]+$/', '', basename($filename));

		$metadata = [
			'post_mime_type' => $file_type['type'],
			'post_title' => $title,
			'post_content' => '',
			'post_status' => 'inherit',
			'guid' => $attachment['url']
		];

		// insert attachment to database and return attachment id
		$attachment_id = wp_insert_attachment( $metadata, $attachment['url'] );

		$inserted_metadata = wp_generate_attachment_metadata($attachment_id, $filename);

		wp_update_attachment_metadata($attachment_id, $inserted_metadata);

		//add_post_meta($attachment_id, '_wcoa_order_id', $this->order_id, true);

		add_post_meta($this->order_id, '_wcoa_attachment_id', $attachment_id, false);

		return [
			'id' => $attachment_id,
			'title' => $title,
			'url' => $attachment['url']
		];
	}

	public static function get_list(int $order_id = 0, int $user_id = 0)
	{
		if ($user_id !== 0)
			return self::prepare_customer_list($user_id);

		return self::prepare_list($order_id);
	}

	private static function prepare_list(int $order_id = 0)
	{
		global $wpdb;

		$sql_check = "SELECT COUNT(*) FROM $wpdb->postmeta AS order_meta
				JOIN $wpdb->postmeta AS attachment_meta ON order_meta.meta_value = attachment_meta.post_id
				JOIN $wpdb->posts AS attachments ON order_meta.meta_value = attachments.ID
				WHERE order_meta.meta_key = '_wcoa_attachment_id' and attachment_meta.meta_key = '_wp_attached_file'";

		if ($order_id !== 0)
			$sql_check .= " AND order_meta.post_id = $order_id;";

		$counter = $wpdb->get_var($sql_check);

		if ($counter <= 0)
			return [];

		$sql = "SELECT order_meta.post_id AS order_id, order_meta.meta_value AS post_id, attachments.post_author,
       			attachments.post_date, attachments.post_title, attachments.guid FROM $wpdb->postmeta AS order_meta
				JOIN $wpdb->postmeta AS attachment_meta ON order_meta.meta_value = attachment_meta.post_id
				JOIN $wpdb->posts AS attachments ON order_meta.meta_value = attachments.ID
				WHERE order_meta.meta_key = '_wcoa_attachment_id' AND attachment_meta.meta_key = '_wp_attached_file'";

		if ($order_id !== 0)
			$sql .= " AND order_meta.post_id = $order_id";

		return $wpdb->get_results($sql, ARRAY_A);

	}

	public static function prepare_customer_list(int $user_id)
	{
		global $wpdb;

		$sql_check = "SELECT COUNT(*) FROM $wpdb->posts AS attachment
                      JOIN $wpdb->postmeta AS attachment_meta ON (attachment_meta.meta_value = attachment.ID)
                      JOIN $wpdb->postmeta AS orders ON attachment_meta.post_id = orders.post_id
                      WHERE attachment.post_type = 'attachment' AND attachment_meta.meta_key = '_wcoa_attachment_id'
                      AND orders.meta_key = '_customer_user' AND attachment.post_mime_type != '' AND orders.meta_value = $user_id;";

		$counter = $wpdb->get_var($sql_check);

		if ($counter <= 0)
			return [];

		$sql = "SELECT orders.post_id AS 'order_id', attachment.post_date, attachment.guid FROM $wpdb->posts AS attachment
                JOIN $wpdb->postmeta AS attachment_meta ON (attachment_meta.meta_value = attachment.ID)
                JOIN $wpdb->postmeta AS orders ON attachment_meta.post_id = orders.post_id
                WHERE attachment.post_type = 'attachment' AND attachment_meta.meta_key = '_wcoa_attachment_id'
                AND orders.meta_key = '_customer_user' AND attachment.post_mime_type != '' AND orders.meta_value = $user_id;";

		return $wpdb->get_results($sql, ARRAY_A);

	}

	public static function get_url(int $order_id, string $order_key, int $attachment_id = 0)
	{
		global $wpdb;

		$counter = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->postmeta WHERE post_id = $order_id AND meta_value = '$order_key';");

		if ($counter < 1)
			return false;

		if ($attachment_id === 0)
			$attachment_id = $wpdb->get_var("SELECT MIN(meta_value) AS qty FROM $wpdb->postmeta where post_id = $order_id and meta_key = '_wcoa_attachment_id'");

		$url = get_the_guid($attachment_id);

		if ($url === '' || str_contains($url, '?p=1'))
			return false;

		return $url;
	}

	public static function get_public_url(int $order_id, int $attachment_id)
	{
		global $wpdb;

		$key = $wpdb->get_var("SELECT meta_value FROM $wpdb->postmeta WHERE post_id = $order_id AND meta_key = '_order_key'");

		if (empty($key))
			return false;

		$path = "?wcoa_attachment_for_order=$order_id&key=$key&id=$attachment_id";

		return get_home_url(null, $path);

	}

}


