<?php

class WCOA_Options
{

	private $options;

	public function __construct()
	{
		add_action( 'admin_init', [$this, 'main'] );

		$this->options = get_option( 'wcoa_general' );
	}

	public function main()
	{
		register_setting( 'wcoa_general', 'wcoa_general', [$this, 'validate'] );

		add_settings_section( 'email_template', __('Email options','woocommerce'), [$this, 'section_email_template_description'], 'wcoa_general_page' );

		add_settings_field('option_email_header', __('Subject','woocommerce'), [$this, 'option_input_text'], 'wcoa_general_page', 'email_template', self::params_email_header());
		add_settings_field( 'option_email_content', __('Message','woocommerce'), [$this, 'option_input_text'], 'wcoa_general_page', 'email_template', self::params_email_content());
		add_settings_field( 'option_email_button', __('Button text','woocommerce'), [$this, 'option_input_text'], 'wcoa_general_page', 'email_template', self::params_email_button());
		add_settings_field( 'option_email_enabled', __('Automatic email notifications','sld-wcoa'), [$this, 'option_email_enabled'], 'wcoa_general_page', 'email_template' );
		add_settings_field( 'option_completed_email_enabled', __('Completed order email','sld-wcoa'), [$this, 'option_completed_email_enabled'], 'wcoa_general_page', 'email_template' );

	}

	public function section_email_template_description()
	{
		_e('Customizing attachments email notifications.','sld-wcoa');
	}

	private static function params_email_header(): array
	{
		return [
			'tag' => 'input',
			'id' => 'option_email_header',
			'name' => 'message_header',
			'style' => [ 'wcoa-input-400' ],
			'value' => 'message_header',
			'placeholder' => 'New attachment to the order {order_number}',
			'label' => esc_html__('Text to appear the email subject.', 'sld-wcoa')
			           . " " . sprintf( esc_html__('Available placeholders: %s', 'woocommerce'), '<code>{site_title}</code>, <code>{order_number}</code>')
		];
	}

	private static function params_email_content(): array
	{
		return [
			'tag' => 'textarea',
			'id' => 'option_email_content',
			'name' => 'message_content',
			'style' => [ 'wcoa-input-400' ],
			'value' => 'message_content',
			'placeholder' => 'An attachment has been added to your order {order_number}. Click the button below to view it.',
			//'label' => sprintf( esc_html__('Email content with attachment. Possibility to use %s and %s tags.','sld-wcoa'),'<code>{site_title}</code>', '<code>{order_id}</code>')
			'label' => esc_html__('Text to appear the main email content.', 'sld-wcoa')
			           . " " . sprintf( esc_html__('Available placeholders: %s', 'woocommerce'), '<code>{site_title}</code>, <code>{order_number}</code>')
		];
	}

	private static function params_email_button(): array
	{
		return [
			'tag' => 'input',
			'id' => 'option_email_button',
			'name' => 'button_text',
			'style' => [ 'wcoa-input-200' ],
			'value' => 'button_text',
			'placeholder' => esc_html__('Preview', 'woocommerce'),
			'label' => esc_html__('Attachment preview button text.', 'sld-wcoa')
		];
	}

	public function option_input_text(array $args)
	{
		$style = implode(' ', $args['style']);

		$content = null;

		if ( isset($this->options[$args['value']]) )
			$content = esc_attr( $this->options[$args['value']] );

		print "<{$args['tag']} id='{$args['id']}' name='wcoa_general[{$args['name']}]' class='{$style}' type='text' value='{$content}' placeholder='{$args['placeholder']}' >";

		if ($args['tag'] === 'textarea')
			print "{$content}</{$args['tag']}>";

		print "<p for='{$args['id']}'>" . $args['label'] ."</p>";
	}

	public function option_email_enabled()
	{
		$content = null;

			if ( isset($this->options['email_enabled']) && $this->options['email_enabled'] === true )
				$content = 'checked';

		print "<input id='option_email_enabled' name='wcoa_general[email_enabled]' type='checkbox' value='1' {$content}/>";
		print "<label for='option_email_enabled'>" . esc_html__('Enable auto-send messages after addition attachment.', 'sld-wcoa') ."</label>";
	}

	public function option_completed_email_enabled()
	{
		$content = null;

			if ( isset($this->options['completed_email_enabled']) && $this->options['completed_email_enabled'] === true )
				$content = 'checked';

		print "<input id='option_completed_email_enabled' name='wcoa_general[completed_email_enabled]' type='checkbox' value='1' {$content}/>";
		print "<label for='option_completed_email_enabled'>" . esc_html__('Add attachment information to completed order email.', 'sld-wcoa') ."</label>";
	}

	public function validate(array $input): array
	{
		$new = [];

		if (isset($input['message_header']))
			$new['message_header'] = trim( $input['message_header'] );

		if (isset($input['message_content']))
			$new['message_content'] = trim( $input['message_content'] );

		if (isset($input['button_text']))
			$new['button_text'] = trim( $input['button_text'] );

		if (isset($input['email_enabled']) && trim($input['email_enabled']) == 1)
		{
			$new['email_enabled'] = true;
		} else {
			$new['email_enabled'] = false;
		}

		if (isset($input['completed_email_enabled']) && trim($input['completed_email_enabled']) == 1)
		{
			$new['completed_email_enabled'] = true;
		} else {
			$new['completed_email_enabled'] = false;
		}

		return $new;
	}

	public static function get($option)
	{
		$result = false;

		if ( isset( get_option( 'wcoa_general' )[$option] ) )
			$result = get_option( 'wcoa_general' )[$option];

		return $result;
	}

}

new WCOA_Options();

